==> react-lds-8.7.0.tgz: package/es/components/Carousel/CarouselPanel.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/es7.object.get-own-property-descriptors";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { keys.push.apply(keys, Object.getOwnPropertySymbols(object)); } if (enumerableOnly) keys = keys.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var CarouselPanel = function CarouselPanel(props) {
  var active = props.active,
      backgroundStyle = props.backgroundStyle,
      children = props.children,
      className = props.className,
      id = props.id,
      imageUrl = props.imageUrl,
      onKeyboardInteraction = props.onKeyboardInteraction,
      title = props.title,
      rest = _objectWithoutProperties(props, ["active", "backgroundStyle", "children", "className", "id", "imageUrl", "onKeyboardInteraction", "title"]);

  var sldsClasses = ['slds-carousel__panel', className];
  var tabIndex = active ? 0 : -1;
  var renderedImage = backgroundStyle ? React.createElement("div", {
    alt: title,
    className: "slds-carousel__image",
    style: _objectSpread({}, backgroundStyle, {
      backgroundImage: "url('".concat(imageUrl, "')")
    })
  }) : React.createElement("div", {
    className: "slds-carousel__image"
  }, React.createElement("img", {
    src: imageUrl,
    alt: title
  }));
  return React.createElement("div", _extends({}, rest, {
    className: cx(sldsClasses),
    id: id,
    role: "tabpanel",
    "aria-hidden": !active,
    "aria-labelledby": "".concat(id, "-indicator")
  }), React.createElement("a", {
    className: "slds-carousel__panel-action slds-text-link_reset",
    onKeyDown: onKeyboardInteraction,
    tabIndex: tabIndex
  }, renderedImage, React.createElement("div", {
    className: "slds-carousel__content"
  }, React.createElement("h2", {
    className: "slds-carousel__content-title"
  }, title), React.createElement("p", null, children))));
};

CarouselPanel.defaultProps = {
  active: false,
  backgroundStyle: null,
  children: [],
  className: null,
  onKeyboardInteraction: null
};
CarouselPanel.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * indicates whether the panel is currently active
   */
  active: PropTypes.bool,

  /**
   * renders the image as background image and adds the given style
   */
  backgroundStyle: PropTypes.object,

  /**
   * list of carousel panels
   */
  children: PropTypes.node,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * unique panel id
   */
  id: PropTypes.string.isRequired,

  /**
   * url for the panel image
   */
  imageUrl: PropTypes.string.isRequired,

  /**
   * Callback for keyboard interaction on an active panel.
   */
  onKeyboardInteraction: PropTypes.func,

  /**
   * title text
   */
  title: PropTypes.string.isRequired
} : {};
export default CarouselPanel;

==> react-lds-9.1.0.tgz: package/es/components/Carousel/CarouselPanel.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.array.filter";
import "core-js/modules/es.array.for-each";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-own-property-descriptor";
import "core-js/modules/es.object.get-own-property-descriptors";
import "core-js/modules/es.object.keys";
import "core-js/modules/web.dom-collections.for-each";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var CarouselPanel = function CarouselPanel(props) {
  var active = props.active,
      backgroundStyle = props.backgroundStyle,
      children = props.children,
      className = props.className,
      id = props.id,
      imageUrl = props.imageUrl,
      onKeyboardInteraction = props.onKeyboardInteraction,
      title = props.title,
      rest = _objectWithoutProperties(props, ["active", "backgroundStyle", "children", "className", "id", "imageUrl", "onKeyboardInteraction", "title"]);

  var sldsClasses = ['slds-carousel__panel', className];
  var tabIndex = active ? 0 : -1;
  var renderedImage = backgroundStyle ? React.createElement("div", {
    alt: title,
    className: "slds-carousel__image",
    style: _objectSpread({}, backgroundStyle, {
      backgroundImage: "url('".concat(imageUrl, "')")
    })
  }) : React.createElement("div", {
    className: "slds-carousel__image"
  }, React.createElement("img", {
    src: imageUrl,
    alt: title
  }));
  return React.createElement("div", _extends({}, rest, {
    className: cx(sldsClasses),
    id: id,
    role: "tabpanel",
    "aria-hidden": !active,
    "aria-labelledby": "".concat(id, "-indicator")
  }), React.createElement("a", {
    className: "slds-carousel__panel-action slds-text-link_reset",
    onKeyDown: onKeyboardInteraction,
    tabIndex: tabIndex
  }, renderedImage, React.createElement("div", {
    className: "slds-carousel__content"
  }, React.createElement("h2", {
    className: "slds-carousel__content-title"
  }, title), React.createElement("p", null, children))));
};

CarouselPanel.defaultProps = {
  active: false,
  backgroundStyle: null,
  children: [],
  className: null,
  onKeyboardInteraction: null
};
CarouselPanel.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * indicates whether the panel is currently active
   */
  active: PropTypes.bool,

  /**
   * renders the image as background image and adds the given style
   */
  backgroundStyle: PropTypes.object,

  /**
   * list of carousel panels
   */
  children: PropTypes.node,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * unique panel id
   */
  id: PropTypes.string.isRequired,

  /**
   * url for the panel image
   */
  imageUrl: PropTypes.string.isRequired,

  /**
   * Callback for keyboard interaction on an active panel.
   */
  onKeyboardInteraction: PropTypes.func,

  /**
   * title text
   */
  title: PropTypes.string.isRequired
} : {};
export default CarouselPanel;
